@@ -1,4 +1,5 @@
 //! **FixedBitSet** is a simple fixed size set of bits.
+#![doc(html_root_url="https://docs.rs/fixedbitset/0.1/")]
 
 use std::ops::Index;
 
@@ -16,7 +17,7 @@ fn div_rem(x: usize, d: usize) -> (usize, usize)
 
 /// **FixedBitSet** is a simple fixed size set of bits that can
 /// be enabled (1 / **true**) or disabled (0 / **false**).
-#[derive(Debug, PartialEq, Eq, PartialOrd, Ord, Hash)]
+#[derive(Debug, PartialEq, Eq, PartialOrd, Ord, Hash, Default)]
 pub struct FixedBitSet {
     data: Vec<Block>,
     /// length in bits
@@ -107,6 +108,26 @@ impl FixedBitSet
         }
     }
 
+    /// Copies boolean value from specified bit to the specified bit.
+    ///
+    /// **Panics** if **to** is out of bounds.
+    #[inline]
+    pub fn copy_bit(&mut self, from: usize, to: usize)
+    {
+        assert!(from < self.length);
+        assert!(to < self.length);
+        let (to_block, t) = div_rem(to, BITS);
+        let enabled = self.contains(from);
+        unsafe {
+            let to_elt = self.data.get_unchecked_mut(to_block);
+            if enabled {
+                *to_elt |= 1 << t;
+            } else {
+                *to_elt &= !(1 << t);
+            }
+        }
+    }
+
     /// View the bitset as a slice of `u32` blocks
     #[inline]
     pub fn as_slice(&self) -> &[u32]
@@ -136,6 +157,9 @@ impl Clone for FixedBitSet
 
 /// Return **true** if the bit is enabled in the bitset,
 /// or **false** otherwise.
+///
+/// Note: bits outside the capacity are always disabled, and thus
+/// indexing a FixedBitSet will not panic.
 impl Index<usize> for FixedBitSet
 {
     type Output = bool;
@@ -194,3 +218,24 @@ fn grow() {
     fb.set(64, true);
     assert!(fb.contains(64));
 }
+
+#[test]
+fn copy_bit() {
+    let mut fb = FixedBitSet::with_capacity(48);
+    for i in 0..fb.len() {
+        fb.set(i, true);
+    }
+    fb.set(42, false);
+    fb.copy_bit(42, 2);
+    assert!(!fb.contains(42));
+    assert!(!fb.contains(2));
+    assert!(fb.contains(1));
+    fb.copy_bit(1, 42);
+    assert!(fb.contains(42));
+}
+
+#[test]
+fn default() {
+    let fb = FixedBitSet::default();
+    assert_eq!(fb.len(), 0);
+}
